==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/elements/te0120.f <==
      SUBROUTINE TE0120(OPTION,NOMTE)
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ELEMENTS  DATE 30/03/2004   AUTEUR CIBHHLV L.VIVAN 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.

C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.

C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================

      IMPLICIT NONE
      CHARACTER*16 OPTION,NOMTE
C ......................................................................
C    - FONCTION REALISEE: OPTIMISATION LOCALE POUR LES LOIS DELOCALISEES
C                         RESOLUTION DU PROBLEME D'ECOULEMENT
C    - OPTION           : DECO_LOCA
C ......................................................................


C --------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ---------------------
      CHARACTER*32 JEXNUM,JEXNOM,JEXR8,JEXATR
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
C --------- FIN  DECLARATIONS  NORMALISEES  JEVEUX ---------------------

      CHARACTER*8 TYPMOD(2)

      INTEGER JGANO,NDIM,NNO,NNOS,NPG,JTAB(7),IRET
      INTEGER IPOIDS,IVF,IGRAD
      INTEGER IDFDE,IGEOM
      INTEGER IMATE,ITREF,ITEMPM,ITEMPP,IPROJ,IRESID
      INTEGER IDEPLM,ICONTM,IDDEPL,ICOMPO,ICARCR,IR,IENER
      INTEGER IVARIM,IVADEP,ILAGRP,IVARIX,LGPG,IVARIP

      REAL*8  VFF(126),DFF(378),DFDI1(24),DFDI2(81)
      INTEGER N,K
C     ------------------------------------------------------------------
C
C   DECODAGE DE LA MODELISATION ET DE LA DIMENSION DE L'ESPACE
      IF (NOMTE(3:4).EQ.'AX') THEN
        TYPMOD(1) = 'AXIS    '
      ELSE IF (NOMTE(3:4).EQ.'CP') THEN
        TYPMOD(1) = 'C_PLAN  '
      ELSE IF (NOMTE(3:4).EQ.'DP') THEN
        TYPMOD(1) = 'D_PLAN  '
      ELSE
        TYPMOD(1) = '3D      '
      END IF

C   FONCTIONS DE FORMES ET POINTS DE GAUSS

      CALL ELREF4(' ','RIGI',NDIM,NNO,NNOS,NPG,IPOIDS,IVF,IDFDE,JGANO)

C -- PASSAGE P2 --> P1

      CALL EFP2P1(NOMTE,NPG,IVF,IDFDE,VFF,DFF,NNOS)


C PARAMETRES EN ENTREE
      CALL JEVECH('PGEOMER','L',IGEOM)
      CALL JEVECH('PMATERC','L',IMATE)
      CALL JEVECH('PDEPLMR','L',IDEPLM)
      CALL JEVECH('PCONTMR','L',ICONTM)
      CALL JEVECH('PDEPLDR','L',IDDEPL)
      CALL JEVECH('PCOMPOR','L',ICOMPO)
      CALL JEVECH('PCARCRI','L',ICARCR)
      CALL JEVECH('PPENCST','L',IR)
      CALL JEVECH('PVARDEP','L',IVADEP)
      CALL JEVECH('PLAGDEP','L',ILAGRP)
      CALL JEVECH('PVARIMR','L',IVARIM)
      CALL TECACH('OON','PVARIMR',7,JTAB,IRET)
      LGPG = MAX(JTAB(6),1)*JTAB(7)


C VARIABLES DE COMMANDE
      CALL JEVECH('PTEREF','L',ITREF)
      CALL JEVECH('PTEMPMR','L',ITEMPM)
      CALL JEVECH('PTEMPPR','L',ITEMPP)


C PARAMETRES EN SORTIE
      CALL JEVECH('PPROJEC','E',IPROJ)
      CALL JEVECH('PRESIDU','E',IRESID)
      CALL JEVECH('PGRADIA','E',IGRAD)
      CALL JEVECH('PENEREL','E',IENER)
      CALL JEVECH('PVARIPR','E',IVARIP)
      CALL JEVECH('PVARIMP','L',IVARIX)
      CALL R8COPY(NPG*LGPG,ZR(IVARIX),1,ZR(IVARIP),1)


C CALCUL DES VARIABLES DELOCALISEES PAR MINIMISATION LOCALE

      IF (NDIM.EQ.2) THEN
        CALL DELOCA(NDIM,OPTION,TYPMOD,NPG,IPOIDS,NNO,IVF,
     &              IDFDE,DFDI2,NNOS,VFF,DFF,
     &              DFF,DFF(1+NNOS*NPG),DFDI1,ZR(IGEOM),ZI(IMATE),
     &              ZK16(ICOMPO),ZR(ICARCR),ZR(IR),ZR(ITREF),ZR(ITEMPM),
     &              ZR(ITEMPP),ZR(IDEPLM),ZR(ICONTM),ZR(IDDEPL),LGPG,
     &              ZR(IVARIM),ZR(IVADEP),ZR(ILAGRP),ZR(IPROJ),
     &              ZR(IRESID),ZR(IGRAD),ZR(IENER),ZR(IVARIP))

      ELSE
        CALL DELOCA(NDIM,OPTION,TYPMOD,NPG,IPOIDS,NNO,IVF,
     &              IDFDE,DFDI2,NNOS,VFF,DFF,
     &              DFF(2),DFF(3),DFDI1,ZR(IGEOM),ZI(IMATE),
     &              ZK16(ICOMPO),ZR(ICARCR),ZR(IR),ZR(ITREF),ZR(ITEMPM),
     &              ZR(ITEMPP),ZR(IDEPLM),ZR(ICONTM),ZR(IDDEPL),LGPG,
     &              ZR(IVARIM),ZR(IVADEP),ZR(ILAGRP),ZR(IPROJ),
     &              ZR(IRESID),ZR(IGRAD),ZR(IENER),ZR(IVARIP))
      END IF


      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/elements/te0120.f <==
      SUBROUTINE TE0120(OPTION,NOMTE)
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ELEMENTS  DATE 16/12/2004   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.

C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.

C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================

      IMPLICIT NONE
      CHARACTER*16 OPTION,NOMTE
C ......................................................................
C    - FONCTION REALISEE: OPTIMISATION LOCALE POUR LES LOIS DELOCALISEES
C                         RESOLUTION DU PROBLEME D'ECOULEMENT
C    - OPTION           : DECO_LOCA
C ......................................................................


C --------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ---------------------
      CHARACTER*32 JEXNUM,JEXNOM,JEXR8,JEXATR
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
C --------- FIN  DECLARATIONS  NORMALISEES  JEVEUX ---------------------

      CHARACTER*8 TYPMOD(2)

      INTEGER JGANO,NDIM,NNO,NNOS,NPG,JTAB(7),IRET
      INTEGER IPOIDS,IVF,IGRAD
      INTEGER IDFDE,IGEOM
      INTEGER IMATE,ITREF,ITEMPM,ITEMPP,IPROJ,IRESID
      INTEGER IDEPLM,ICONTM,IDDEPL,ICOMPO,ICARCR,IR,IENER
      INTEGER IVARIM,IVADEP,ILAGRP,IVARIX,LGPG,IVARIP

      REAL*8  VFF(126),DFF(378),DFDI1(24),DFDI2(81)
      INTEGER N,K
C     ------------------------------------------------------------------
C
C   DECODAGE DE LA MODELISATION ET DE LA DIMENSION DE L'ESPACE
      IF (NOMTE(3:4).EQ.'AX') THEN
        TYPMOD(1) = 'AXIS    '
      ELSE IF (NOMTE(3:4).EQ.'CP') THEN
        TYPMOD(1) = 'C_PLAN  '
      ELSE IF (NOMTE(3:4).EQ.'DP') THEN
        TYPMOD(1) = 'D_PLAN  '
      ELSE
        TYPMOD(1) = '3D      '
      END IF

C   FONCTIONS DE FORMES ET POINTS DE GAUSS

      CALL ELREF4(' ','RIGI',NDIM,NNO,NNOS,NPG,IPOIDS,IVF,IDFDE,JGANO)

C -- PASSAGE P2 --> P1

      CALL EFP2P1(NOMTE,NPG,IVF,IDFDE,VFF,DFF,NNOS)


C PARAMETRES EN ENTREE
      CALL JEVECH('PGEOMER','L',IGEOM)
      CALL JEVECH('PMATERC','L',IMATE)
      CALL JEVECH('PDEPLMR','L',IDEPLM)
      CALL JEVECH('PCONTMR','L',ICONTM)
      CALL JEVECH('PDEPLDR','L',IDDEPL)
      CALL JEVECH('PCOMPOR','L',ICOMPO)
      CALL JEVECH('PCARCRI','L',ICARCR)
      CALL JEVECH('PPENCST','L',IR)
      CALL JEVECH('PVARDEP','L',IVADEP)
      CALL JEVECH('PLAGDEP','L',ILAGRP)
      CALL JEVECH('PVARIMR','L',IVARIM)
      CALL TECACH('OON','PVARIMR',7,JTAB,IRET)
      LGPG = MAX(JTAB(6),1)*JTAB(7)


C VARIABLES DE COMMANDE
      CALL JEVECH('PTEREF','L',ITREF)
      CALL JEVECH('PTEMPMR','L',ITEMPM)
      CALL JEVECH('PTEMPPR','L',ITEMPP)


C PARAMETRES EN SORTIE
      CALL JEVECH('PPROJEC','E',IPROJ)
      CALL JEVECH('PRESIDU','E',IRESID)
      CALL JEVECH('PGRADIA','E',IGRAD)
      CALL JEVECH('PENEREL','E',IENER)
      CALL JEVECH('PVARIPR','E',IVARIP)
      CALL JEVECH('PVARIMP','L',IVARIX)
      CALL DCOPY(NPG*LGPG,ZR(IVARIX),1,ZR(IVARIP),1)


C CALCUL DES VARIABLES DELOCALISEES PAR MINIMISATION LOCALE

      IF (NDIM.EQ.2) THEN
        CALL DELOCA(NDIM,OPTION,TYPMOD,NPG,IPOIDS,NNO,IVF,
     &              IDFDE,DFDI2,NNOS,VFF,DFF,
     &              DFF,DFF(1+NNOS*NPG),DFDI1,ZR(IGEOM),ZI(IMATE),
     &              ZK16(ICOMPO),ZR(ICARCR),ZR(IR),ZR(ITREF),ZR(ITEMPM),
     &              ZR(ITEMPP),ZR(IDEPLM),ZR(ICONTM),ZR(IDDEPL),LGPG,
     &              ZR(IVARIM),ZR(IVADEP),ZR(ILAGRP),ZR(IPROJ),
     &              ZR(IRESID),ZR(IGRAD),ZR(IENER),ZR(IVARIP))

      ELSE
        CALL DELOCA(NDIM,OPTION,TYPMOD,NPG,IPOIDS,NNO,IVF,
     &              IDFDE,DFDI2,NNOS,VFF,DFF,
     &              DFF(2),DFF(3),DFDI1,ZR(IGEOM),ZI(IMATE),
     &              ZK16(ICOMPO),ZR(ICARCR),ZR(IR),ZR(ITREF),ZR(ITEMPM),
     &              ZR(ITEMPP),ZR(IDEPLM),ZR(ICONTM),ZR(IDDEPL),LGPG,
     &              ZR(IVARIM),ZR(IVADEP),ZR(ILAGRP),ZR(IPROJ),
     &              ZR(IRESID),ZR(IGRAD),ZR(IENER),ZR(IVARIP))
      END IF


      END
